#   pyRCV2: Preferential vote counting
#   Copyright © 2020  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

import math

class NativeInt:
	"""
	Wrapper for Python int
	"""
	
	def __init__(self, val):
		if isinstance(val, NativeInt):
			self.impl = val.impl
		else:
			self.impl = int(val)
	
	def pp(self, dp):
		"""Pretty print to specified number of decimal places"""
		return str(self.impl)
	
	def to_rational(self):
		"""Convert to an instance of Rational"""
		from pyRCV2.numbers import Rational
		return Rational(self.impl)
	
	def __add__(self, other):
		return NativeInt(self.impl + other.impl)
	def __sub__(self, other):
		return NativeInt(self.impl - other.impl)
	def __mul__(self, other):
		return NativeInt(self.impl * other.impl)
	def __truediv__(self, other):
		return NativeInt(self.impl / other.impl)
	
	def __eq__(self, other):
		return self.impl == other.impl
	def __gt__(self, other):
		return self.impl > other.impl
	def __ge__(self, other):
		return self.impl >= other.impl
	def __lt__(self, other):
		return self.impl < other.impl
	def __le__(self, other):
		return self.impl <= other.impl
	
	def __floor__(self):
		return NativeInt(math.floor(self.impl))
